==> qtjambi-uic-5.15.17-sources.jar: io/qt/uic/ui4/DomRectF.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomRectF</code></p>
 */
public class DomRectF extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomRectF::<wbr>DomRectF()</code></p>
     */
    public DomRectF(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomRectF instance);
    
    /**
     * <p>See <code>DomRectF::<wbr>clearElementHeight()</code></p>
     */
    @QtUninvokable
    public final void clearElementHeight(){
        clearElementHeight_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHeight_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>clearElementWidth()</code></p>
     */
    @QtUninvokable
    public final void clearElementWidth(){
        clearElementWidth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementWidth_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>clearElementX()</code></p>
     */
    @QtUninvokable
    public final void clearElementX(){
        clearElementX_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementX_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>clearElementY()</code></p>
     */
    @QtUninvokable
    public final void clearElementY(){
        clearElementY_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementY_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>elementHeight()const</code></p>
     */
    @QtUninvokable
    public final double elementHeight(){
        return elementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>elementWidth()const</code></p>
     */
    @QtUninvokable
    public final double elementWidth(){
        return elementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>elementX()const</code></p>
     */
    @QtUninvokable
    public final double elementX(){
        return elementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>elementY()const</code></p>
     */
    @QtUninvokable
    public final double elementY(){
        return elementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>hasElementHeight()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHeight(){
        return hasElementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>hasElementWidth()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementWidth(){
        return hasElementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>hasElementX()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementX(){
        return hasElementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>hasElementY()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementY(){
        return hasElementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomRectF::<wbr>setElementHeight(double)</code></p>
     */
    @QtUninvokable
    public final void setElementHeight(double a){
        setElementHeight_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHeight_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr>setElementWidth(double)</code></p>
     */
    @QtUninvokable
    public final void setElementWidth(double a){
        setElementWidth_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementWidth_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr>setElementX(double)</code></p>
     */
    @QtUninvokable
    public final void setElementX(double a){
        setElementX_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementX_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr>setElementY(double)</code></p>
     */
    @QtUninvokable
    public final void setElementY(double a){
        setElementY_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementY_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomRectF(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-5.15.19-sources.jar: io/qt/uic/ui4/DomRectF.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomRectF</code></p>
 */
public class DomRectF extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomRectF::<wbr/>DomRectF()</code></p>
     */
    public DomRectF(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomRectF instance);
    
    /**
     * <p>See <code>DomRectF::<wbr/>clearElementHeight()</code></p>
     */
    @QtUninvokable
    public final void clearElementHeight(){
        clearElementHeight_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHeight_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>clearElementWidth()</code></p>
     */
    @QtUninvokable
    public final void clearElementWidth(){
        clearElementWidth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementWidth_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>clearElementX()</code></p>
     */
    @QtUninvokable
    public final void clearElementX(){
        clearElementX_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementX_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>clearElementY()</code></p>
     */
    @QtUninvokable
    public final void clearElementY(){
        clearElementY_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementY_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>elementHeight()const</code></p>
     */
    @QtUninvokable
    public final double elementHeight(){
        return elementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>elementWidth()const</code></p>
     */
    @QtUninvokable
    public final double elementWidth(){
        return elementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>elementX()const</code></p>
     */
    @QtUninvokable
    public final double elementX(){
        return elementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>elementY()const</code></p>
     */
    @QtUninvokable
    public final double elementY(){
        return elementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>hasElementHeight()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHeight(){
        return hasElementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>hasElementWidth()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementWidth(){
        return hasElementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>hasElementX()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementX(){
        return hasElementX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>hasElementY()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementY(){
        return hasElementY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomRectF::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomRectF::<wbr/>setElementHeight(double)</code></p>
     */
    @QtUninvokable
    public final void setElementHeight(double a){
        setElementHeight_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHeight_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr/>setElementWidth(double)</code></p>
     */
    @QtUninvokable
    public final void setElementWidth(double a){
        setElementWidth_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementWidth_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr/>setElementX(double)</code></p>
     */
    @QtUninvokable
    public final void setElementX(double a){
        setElementX_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementX_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr/>setElementY(double)</code></p>
     */
    @QtUninvokable
    public final void setElementY(double a){
        setElementY_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementY_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomRectF::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomRectF(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}
